require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module UDS
    module Bucket

      # DTO for creation of the new bucket.
      class BucketCreate < UU::OS::REST::DTO

        # Code of the bucket (must be unique).
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Name of the bucket.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Description of the bucket.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # Capacity of the bucket (in megabytes). Use -1 for unlimited capacity (must be allowed by
        # system configuration). If not set, then maximum capacity allowed by system configuration
        # is used.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :capacity

        # Time (in minutes) after which blobs in this bucket will be automatically deleted.
        # Use -1 for unlimited blob timeout.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :blob_timeout

        # Maximum allowed size of single blob (in megabytes, must not be greater than capacity).
        # If not set (or set to -1), then the maximum blob size is dynamic, based on bucket
        # remaining capacity.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :max_blob_size

        # Maximum total size allowed to be stored by single user (in megabytes). If not set
        # (or set to -1) no size limit per user is applied.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :max_total_size_per_user

        # Maximum total size allowed to be stored by single application (in megabytes). If not
        # set (or set to -1) no size limit per application is applied.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :max_total_size_per_app

        # If set to true (default) bucket is created only for specified AppBox (or App instance).
        # In this case only this particular application can manipulate with blobs. If set to false
        # bucket is public for any application, but blob manipulation is restricted to user which
        # created particular blob.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :restricted

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def capacity
          attributes[:capacity]
        end

        def capacity=(val)
          attributes[:capacity] = val
        end

        def blob_timeout
          attributes[:blobTimeout]
        end

        def blob_timeout=(val)
          attributes[:blobTimeout] = val
        end

        def max_blob_size
          attributes[:maxBlobSize]
        end

        def max_blob_size=(val)
          attributes[:maxBlobSize] = val
        end

        def max_total_size_per_user
          attributes[:maxTotalSizePerUser]
        end

        def max_total_size_per_user=(val)
          attributes[:maxTotalSizePerUser] = val
        end

        def max_total_size_per_app
          attributes[:maxTotalSizePerApp]
        end

        def max_total_size_per_app=(val)
          attributes[:maxTotalSizePerApp] = val
        end

        def restricted
          attributes[:restricted]
        end

        def restricted=(val)
          attributes[:restricted] = val
        end

      end

    end
  end
end
